@@ -15,9 +15,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *      Vincent Untz <vuntz@gnome.org>
@@ -1531,10 +1529,8 @@ create_hig_frame (CalendarWindow *calwin,
 						G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
         }
 
-#ifdef HAVE_LIBECAL
 	g_settings_bind (calwin->priv->settings, key, expander, "expanded",
 			 G_SETTINGS_BIND_DEFAULT);
-#endif
 
         return vbox;
 }
