@@ -15,9 +15,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *      Miguel de Icaza
@@ -131,14 +129,10 @@ struct _ClockData {
         time_t             current_time;
         GnomeWallClock    *wall_clock;
 	PanelAppletOrient  orient;
-	int                size;
 	GtkAllocation      old_allocation;
 
 	SystemTimezone *systz;
 
-	int fixed_width;
-	int fixed_height;
-
         GtkWidget *showseconds_check;
         GtkWidget *showdate_check;
         GtkWidget *custom_hbox;
@@ -199,14 +193,6 @@ _clock_get_widget (ClockData  *cd,
 	return GTK_WIDGET (gtk_builder_get_object (cd->builder, name));
 }
 
-static void
-unfix_size (ClockData *cd)
-{
-	cd->fixed_width = -1;
-	cd->fixed_height = -1;
-	gtk_widget_queue_resize (cd->panel_button);
-}
-
 static int
 calculate_minimum_width (GtkWidget   *widget,
 			 const gchar *text)
@@ -820,23 +806,6 @@ do_not_eat_button_press (GtkWidget      *widget,
 	return FALSE;
 }
 
-/* Don't request smaller size then the last one we did, this avoids
-   jumping when proportional fonts are used.  We must take care to
-   call "unfix_size" whenever options are changed or such where
-   we'd want to forget the fixed size */
-static void
-clock_size_request (GtkWidget *clock, GtkRequisition *req, gpointer data)
-{
-	ClockData *cd = data;
-
-	if (req->width > cd->fixed_width)
-		cd->fixed_width = req->width;
-	if (req->height > cd->fixed_height)
-		cd->fixed_height = req->height;
-	req->width = cd->fixed_width;
-	req->height = cd->fixed_height;
-}
-
 static void
 clock_update_text_gravity (GtkWidget *label)
 {
@@ -892,12 +861,6 @@ create_main_clock_label (ClockData *cd)
         GtkWidget *label;
 
         label = gtk_label_new (NULL);
-	g_signal_connect (label, "size_request",
-			  G_CALLBACK (clock_size_request),
-			  cd);
-	g_signal_connect_swapped (label, "style_set",
-				  G_CALLBACK (unfix_size),
-				  cd);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
 	clock_update_text_gravity (label);
 	g_signal_connect (label, "screen-changed",
@@ -995,7 +958,6 @@ create_clock_widget (ClockData *cd)
 
 	cd->props = NULL;
 	cd->orient = -1;
-	cd->size = panel_applet_get_size (PANEL_APPLET (cd->applet));
 
 	update_panel_weather (cd);
 
@@ -1030,7 +992,6 @@ update_orient (ClockData *cd)
 
 	angle = gtk_label_get_angle (GTK_LABEL (cd->clockw));
 	if (angle != new_angle) {
-		unfix_size (cd);
 		gtk_label_set_angle (GTK_LABEL (cd->clockw), new_angle);
                 gtk_label_set_angle (GTK_LABEL (cd->panel_temperature_label), new_angle);
 	}
@@ -1070,7 +1031,6 @@ applet_change_orient (PanelApplet       *applet,
         gtk_orientable_set_orientation (GTK_ORIENTABLE (cd->main_obox), o);
         gtk_orientable_set_orientation (GTK_ORIENTABLE (cd->weather_obox), o);
 
-        unfix_size (cd);
         update_clock (NULL, NULL, cd);
         update_calendar_popup (cd);
 }
@@ -1081,24 +1041,12 @@ panel_button_change_pixel_size (GtkWidget     *widget,
                                 GtkAllocation *allocation,
                                 ClockData	*cd)
 {
-	int new_size;
-
 	if (cd->old_allocation.width  == allocation->width &&
 	    cd->old_allocation.height == allocation->height)
 		return;
 
-	cd->old_allocation.width  = allocation->width;
-	cd->old_allocation.height = allocation->height;
+	cd->old_allocation = *allocation;
 
-	if (cd->orient == PANEL_APPLET_ORIENT_LEFT ||
-	    cd->orient == PANEL_APPLET_ORIENT_RIGHT)
-		new_size = allocation->width;
-	else
-		new_size = allocation->height;
-
-	cd->size = new_size;
-
-        unfix_size (cd);
 	update_clock (NULL, NULL, cd);
 }
 
@@ -1375,9 +1323,6 @@ fill_clock_applet (PanelApplet *applet)
         g_signal_connect (cd->applet_settings, "changed::cities",
                           G_CALLBACK (locations_changed), cd);
 
-	cd->fixed_width = -1;
-	cd->fixed_height = -1;
-
 	cd->applet = GTK_WIDGET (applet);
 
         cd->world = gweather_location_new_world (FALSE);
@@ -1478,6 +1423,8 @@ save_cities_store (ClockData *cd)
 
         g_settings_set_value (cd->applet_settings, "cities",
                               g_variant_builder_end (&builder));
+
+        create_cities_store (cd);
 }
 
 static void
@@ -1495,7 +1442,7 @@ run_prefs_edit_save (GtkButton *button, ClockData *cd)
         const gchar *timezone, *weather_code;
         gchar *city, *name;
 
-        GWeatherLocation *gloc;
+        GWeatherLocation *gloc, *station_loc;
         gfloat lat = 0;
         gfloat lon = 0;
 
@@ -1520,7 +1467,13 @@ run_prefs_edit_save (GtkButton *button, ClockData *cd)
                 return;
         }
 
-        weather_code = gweather_location_get_code (gloc);
+        station_loc = gloc;
+        while (gweather_location_get_level (station_loc) < GWEATHER_LOCATION_WEATHER_STATION) {
+                station_loc = gweather_location_get_children (station_loc)[0];
+                g_assert (station_loc != NULL);
+        }
+
+        weather_code = gweather_location_get_code (station_loc);
         if (gweather_location_entry_has_custom_text (cd->location_entry)) {
                 name = gtk_editable_get_chars (GTK_EDITABLE (cd->location_entry), 0, -1);
         }
@@ -1669,7 +1622,8 @@ edit_clear (ClockData *cd)
         GtkWidget *lon_combo = _clock_get_widget (cd, "edit-location-longitude-combo");
 
         /* clear out the old data */
-        gweather_location_entry_set_location (cd->location_entry, NULL);
+        /* TODO: reinstate after bumping to gweather >= 3.10.1 */
+        //gweather_location_entry_set_location (cd->location_entry, NULL);
         gweather_timezone_menu_set_tzid (cd->zone_combo, NULL);
 
         gtk_entry_set_text (GTK_ENTRY (lat_entry), "");
