@@ -14,9 +14,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *	Mark McLoughlin <mark@skynet.ie>
@@ -73,7 +71,7 @@ typedef struct {
 } MenuPathRootItem;
 
 static MenuPathRootItem root_items [] = {
-	{ APPLICATIONS_MENU, "applications", "applications.menu" },
+	{ APPLICATIONS_MENU, "applications", "gnome-applications.menu" },
 	{ GNOMECC_MENU,      "gnomecc",      "gnomecc.menu"      }
 };
 
