@@ -1286,14 +1286,6 @@ panel_widget_size_request(GtkWidget *widget, GtkRequisition *requisition)
 		}
 	}
 
-
-	if (!panel->packed) {
-		if (panel->orient == GTK_ORIENTATION_HORIZONTAL)
-			requisition->width = panel->size;
-		else
-			requisition->height = panel->size;
-	}
-
 	dont_fill = panel->packed && panel->nb_applets_size_hints != 0;
 
 	if (panel->orient == GTK_ORIENTATION_HORIZONTAL) {
@@ -1503,12 +1495,6 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 		}
 	}
 
-
-	if(panel->orient == GTK_ORIENTATION_HORIZONTAL)
-		panel->thick = allocation->height;
-	else
-		panel->thick = allocation->width;
-
 	panel_widget_set_background_region (panel);
 }
 
@@ -1517,7 +1503,7 @@ panel_widget_is_cursor(PanelWidget *panel, int overlap)
 {
 	GtkWidget       *widget;
 	GtkAllocation   allocation;
-	GdkModifierType modifier_mask;
+	GdkDevice       *device;
 	int             x,y;
 	int             w,h;
 
@@ -1530,7 +1516,8 @@ panel_widget_is_cursor(PanelWidget *panel, int overlap)
 	   !gtk_widget_get_visible(widget))
 		return FALSE;
 
-	gdk_window_get_device_position(gtk_widget_get_window (widget), gtk_get_current_event_device (), &x, &y, &modifier_mask);
+	device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (widget)));
+	gdk_window_get_device_position(gtk_widget_get_window (widget), device, &x, &y, NULL);
 
 	gtk_widget_get_allocation (widget, &allocation);
 	w = allocation.width;
@@ -1702,7 +1689,6 @@ panel_widget_init (PanelWidget *panel)
 	
 	panel->packed        = FALSE;
 	panel->orient        = GTK_ORIENTATION_HORIZONTAL;
-	panel->thick         = PANEL_MINIMUM_WIDTH;
 	panel->size          = G_MAXINT;
 	panel->applet_list   = NULL;
 	panel->drop_widget   = widget;
@@ -1903,11 +1889,12 @@ panel_widget_get_cursorloc (PanelWidget *panel)
 {
 	int             x, y;
 	gboolean        rtl;
-	GdkModifierType modifier_mask;
+	GdkDevice      *device;
 
 	g_return_val_if_fail (PANEL_IS_WIDGET (panel), -1);
 
-	gdk_window_get_device_position(gtk_widget_get_window (GTK_WIDGET (panel)), gtk_get_current_event_device (), &x, &y, &modifier_mask);
+	device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (GTK_WIDGET (panel))));
+	gdk_window_get_device_position(gtk_widget_get_window (GTK_WIDGET (panel)), device, &x, &y, NULL);
 	rtl = gtk_widget_get_direction (GTK_WIDGET (panel)) == GTK_TEXT_DIR_RTL;
 	
 	if (panel->orient == GTK_ORIENTATION_HORIZONTAL)
@@ -2082,13 +2069,14 @@ move_timeout_handler(gpointer data)
 	if(panel->currently_dragged_applet && repeat_if_outside) {
 		GtkWidget       *widget;
 		GtkAllocation   allocation;
-		GdkModifierType modifier_mask;
+		GdkDevice       *device;
 		int             x,y;
 		int             w,h;
 
 		widget = panel->currently_dragged_applet->applet;
 
-		gdk_window_get_device_position(gtk_widget_get_window (widget), gtk_get_current_event_device (), &x, &y, &modifier_mask);
+		device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (widget)));
+		gdk_window_get_device_position(gtk_widget_get_window (widget), device, &x, &y, NULL);
 
 		gtk_widget_get_allocation (widget, &allocation);
 		w = allocation.width;
