@@ -15,9 +15,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *     Mark McLoughlin <mark@skynet.ie>
@@ -1130,7 +1128,7 @@ panel_applet_position_menu (GtkMenu   *menu,
 	PanelApplet    *applet;
 	GtkAllocation   allocation;
 	GtkRequisition  requisition;
-	GdkModifierType modifier_mask;
+	GdkDevice      *device;
 	GdkScreen      *screen;
 	int             menu_x = 0;
 	int             menu_y = 0;
@@ -1148,7 +1146,8 @@ panel_applet_position_menu (GtkMenu   *menu,
 	gtk_widget_get_preferred_size (GTK_WIDGET (menu), &requisition, NULL);
 	gdk_window_get_origin (gtk_widget_get_window (widget),
 			       &menu_x, &menu_y);
-	gdk_window_get_device_position(gtk_widget_get_window (widget), gtk_get_current_event_device (), &pointer_x, &pointer_y, &modifier_mask);
+	device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (widget)));
+	gdk_window_get_device_position(gtk_widget_get_window (widget), device, &pointer_x, &pointer_y, NULL);
 
 	gtk_widget_get_allocation (widget, &allocation);
 
@@ -1236,6 +1235,7 @@ panel_applet_edit_menu_popup (PanelApplet *applet,
 
 	menu = gtk_ui_manager_get_widget (applet->priv->ui_manager,
 					  "/PanelAppletEditPopup");
+	gtk_menu_set_screen (GTK_MENU (menu), gtk_widget_get_screen (GTK_WIDGET (applet)));
 	gtk_menu_popup (GTK_MENU (menu),
 			NULL, NULL,
 			NULL,
